import {
  Component, OnDestroy, OnInit, ViewChild
} from '@angular/core';
import {NgbModal} from '@ng-bootstrap/ng-bootstrap';
import { OrgInterface } from '../../../common/interface/org.interface';
import { ModalTipComponent } from '../../../../..';

@Component({
  moduleId: module.id,
  templateUrl: './organization.management.component.html',
  styleUrls: ['./organization.management.component.css']
})
export class OrganizationManagementComponent implements OnInit, OnDestroy {
  constructor(private orgInterface: OrgInterface,
              private modalService: NgbModal) {

  }

  nodeViewType = 'edit'; // 右侧查看状态 edit | add
  mockData = []; // 模拟数据
  treeOptions = {
    actionBtn: [
      {
        text: '新增',
        cls: 'action-add',
        showText: true,
        fn: nodeData => {
          this.addOrgElement(nodeData);
        }
      }, {
        text: '删除',
        cls: 'action-del',
        showText: true,
        rootHide: true,
        fn: nodeData => {
          this.delOrgElement(nodeData);
        }
      }
    ],
    iconCls: {
      expand: 'tree-icon-expand',
      file: 'tree-icon-file',
      folder: 'tree-icon-folder'
    },
  }; // 树节点操作按钮配置
  selectOrgData; // 选中的树节点数据，本组件自用
  currentOrgData; // 当前选中的数据，传递给子组件使用
  parentOrgForAdd; // 新增子节点时，临时存放新增子节点的父节点的数据
  treeSearch = {
    text: '', // 树搜索内容
    searching: false, // 搜索状态
    result: [], // 搜索结果
  };
  // 各接口的promisse对象
  getOrgTreePromisse;
  addOrgPromisse;
  editOrgPromisse;
  delOrgPromisse;
  getOrgPromisse;
  @ViewChild('tree') tree;

  ngOnInit() {
    this.getOrgTreeData();
  }

  ngOnDestroy() {
    this.destroyPromisse();
  }

  // 当组件被移除的时候，销毁该组件的请求
  destroyPromisse() {
    this.getOrgTreePromisse && this.getOrgTreePromisse.unsubscribe();
    this.addOrgPromisse && this.addOrgPromisse.unsubscribe();
    this.editOrgPromisse && this.editOrgPromisse.unsubscribe();
    this.delOrgPromisse && this.delOrgPromisse.unsubscribe();
    this.getOrgPromisse && this.getOrgPromisse.unsubscribe();
  }

  // 获取组织树数据
  getOrgTreeData() {
    if (this.getOrgTreePromisse) {
      this.getOrgTreePromisse.unsubscribe();
    }
    this.getOrgTreePromisse = this.orgInterface.getOrgTreeData({
      id: 1
    }).subscribe(res => {
      this.mockData = res['result'];
    }, err => {
      alert(JSON.stringify(err));
    });
  }

  // 节点点击事件
  nodeClick(nodeData) {
    this.nodeViewType = 'edit';
    this.tree.selectTreeNode(nodeData);
    this.selectOrgData = nodeData;
    this.queryOrgElement(nodeData);
  }

  // 获取单个组织详细信息
  queryOrgElement(nodeData) {
    if (this.getOrgPromisse) {
      this.getOrgPromisse.unsubscribe();
    }
    this.getOrgPromisse = this.orgInterface.queryOrgElement({
      id: nodeData.id
    }).subscribe(res => {
      this.changeCurrentOrgData(res['result'].torgEntity);
    }, err => {
      alert(JSON.stringify(err));
    });
  }

  // 切换组织节点
  changeCurrentOrgData(data) {
    this.currentOrgData = null;
    setTimeout(() => {
      this.currentOrgData = data;
    }, 1);
  }

  // 节点删除事件
  delOrgElement(nodeData) {
    let childrenNode = this.tree.findChildrensNodeByNode(nodeData);
    if (childrenNode.length > 0) {
      let ids = [];
      for (let i = 0; i < childrenNode.length; i++) {
        ids.push(childrenNode[i].id);
      }
      let modalDialog = this.modalService.open(ModalTipComponent, {
        backdrop: 'static'
      });
      modalDialog.result.then((value) => {
        if (this.delOrgPromisse) {
          this.delOrgPromisse.unsubscribe();
        }
        this.delOrgPromisse = this.orgInterface.delOrgElement({
          ids: (ids.join(',') + '')
        }).subscribe(res => {
          this.tree.deleteNodeById(ids[0]);
        }, err => {
          alert(JSON.stringify(err));
        });
      }).catch(reason => {
      });
    }
  }

  // 节点新增事件
  addOrgElement(item) {
    this.nodeViewType = 'add';
    this.parentOrgForAdd = item;
    this.changeCurrentOrgData({
      'id': '',
      'orgName': '',
      'parentId': item.id,
      'uppOrgName': item.orgName,
      'state': '1',
      'remark': ''
    });
  }

  // 模糊搜索组织名称
  searchTreeNode(ev) {
    this.resetTreeSearch();
    if (!this.treeSearch.text) {
      return;
    }
    this.treeSearch.searching = true;
    this.treeSearch.result = this.tree.fuzzySearchNodesByKey(this.treeSearch.text, 'orgName');
    this.tree.lighthightNodes(this.treeSearch.result);
    this.tree.expandNodes(this.treeSearch.result);
    this.treeSearch.searching = false;
  }

  // 重置树节点的搜索状态
  resetTreeSearch() {
    this.tree.removeLighthightNodes(this.treeSearch.result);
    this.treeSearch.searching = false;
    this.treeSearch.result = [];
  }

  // 保存组织回掉方法
  saveOrgElement(data) {
    if (this.nodeViewType == 'add') {
      data.parentId = this.parentOrgForAdd.id;
      const loadingModal = this.modalService.open('loading', {
        backdrop: 'static'
      });
      if (this.addOrgPromisse) {
        this.addOrgPromisse.unsubscribe();
      }
      this.addOrgPromisse = this.orgInterface.addOrgElement(data).subscribe(res => {
        loadingModal.close();
        let result = res['result'].torgEntity;
        let node = this.tree.insertNode(result, this.parentOrgForAdd);
        this.tree.selectTreeNode(node);
        this.selectOrgData = node;
        this.nodeViewType = 'edit';
        this.changeCurrentOrgData(node);
      }, err => {
        loadingModal.close();
        alert(JSON.stringify(err));
      });
    } else if (this.nodeViewType == 'edit') {
      if (this.editOrgPromisse) {
        this.editOrgPromisse.unsubscribe();
      }
      this.editOrgPromisse = this.orgInterface.updateOrgElement(data).subscribe(res => {
        this.tree.updateNodeData(data, ['orgName', 'state', 'remark']);
      }, err => {
        alert(JSON.stringify(err));
      });
    }
  }
}
