import {
  Component, OnInit, ViewChild
} from '@angular/core';
import {NgbModal} from '@ng-bootstrap/ng-bootstrap';
import { OrgInterface } from '../../../common/interface/org.interface';
import { PostInterface } from '../../../common/interface/post.interface';

@Component({
  moduleId: module.id,
  templateUrl: './post.management.component.html',
  styleUrls: ['./post.management.component.css']
})
export class PostManagementComponent implements OnInit {
  constructor(private orgInterface: OrgInterface,
              private modalService: NgbModal,
              private postInterface: PostInterface) {

  }

  mockData = []; // 模拟数据
  treeOptions = {
    iconCls: {
      expand: 'tree-icon-expand',
      file: 'tree-icon-file',
      folder: 'tree-icon-folder'
    },
  }; // 树节点操作按钮配置
  selectOrgData; // 选中的树节点数据
  currentOrgData;
  treeSearch = {
    text: '', // 树搜索内容
    searching: false, // 搜索状态
    result: [], // 搜索结果
  };
  @ViewChild('tree') tree;

  ngOnInit() {
    this.getOrgTreeData();
  }

  // 获取组织树数据
  getOrgTreeData() {
    this.orgInterface.getOrgTreeData({
      id: 1
    }).subscribe(res => {
      this.mockData = res['result'];
    }, err => {
      alert(JSON.stringify(err));
    });
  }

  // 节点点击事件
  // todo
  nodeClick(nodeData) {
    this.tree.selectTreeNode(nodeData);
    this.selectOrgData = nodeData;
    this.changeCurrentOrgData(nodeData);
  }


  // 切换组织节点
  changeCurrentOrgData(data) {
    this.currentOrgData = null;
    setTimeout(() => {
      this.currentOrgData = data;
    }, 1);
  }


  // 模糊搜索组织名称
  searchTreeNode(ev) {
    this.resetTreeSearch();
    if (!this.treeSearch.text) {
      return;
    }
    this.treeSearch.searching = true;
    this.treeSearch.result = this.tree.fuzzySearchNodesByKey(this.treeSearch.text, 'orgName');
    this.tree.lighthightNodes(this.treeSearch.result);
    this.tree.expandNodes(this.treeSearch.result);
    this.treeSearch.searching = false;
  }

  resetTreeSearch() {
    this.tree.removeLighthightNodes(this.treeSearch.result);
    this.treeSearch.searching = false;
    this.treeSearch.result = [];
  }

}
