import { Component, Input, OnInit, Output, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { Router, NavigationStart, NavigationEnd, NavigationCancel, NavigationError, RoutesRecognized } from '@angular/router';

@Component({
  selector: 'pagination',
  template: `
  <div class="display-flex width-100 flex-end" *ngIf="total!=0">

    <div style="font-size: 12px;color: #666666">
        共{{total}}条
    </div>
    <div class="display-flex" style="margin-left:20px">
        <div class="select-box left" (click)="jumpPage('before')" [ngClass]="{'cursor-pointer':nowPage!=1}"></div>
        <div class="cursor-pointer number" style="margin-left:5px" (click)="jumpPage(1)" [ngClass]="{'selet':nowPage==1}">1</div>
        <div *ngIf="showBeforeDot" style="margin-left:10px">...</div>
        <div class="cursor-pointer number" style="margin-left:10px" *ngFor="let c of showList" (click)="jumpPage(c)" [ngClass]="{'selet':nowPage==c}">{{c}}</div>
        <div *ngIf="showAfterDot" style="margin-left:10px">...</div>
        <div class="cursor-pointer number" *ngIf="maxPage!=1" style="margin-left:10px" (click)="jumpPage(maxPage)" [ngClass]="{'selet':nowPage==maxPage}">{{maxPage}}</div>
        <div class="select-box right" style="margin-left:5px" (click)="jumpPage('after')" [ngClass]="{'cursor-pointer':nowPage!=maxPage}"></div>
    </div>
    <div style="margin-left:20px;font-size: 12px;color: #666666">
        跳转至
        <input [(ngModel)]="jump" type="text" class="jump-input" (keypress)="pressInput($event)"> 页
    </div>
</div>
  `,
  styles: [
    '.jump-input{' +
    'height: 17px;' +
    'width: 17px;' +
    'min-width: 30px;}',

    '.select-box{' +
    'display: flex;' +
    'justify-content: center;}',
    '.selet{' +
    'background-color: #e2e8ed;' +
    'width: 24px;' +
    'height: 24px;' +
    'border-radius: 3px;}',

    '.number{' +
    'width: 24px;' +
    'height: 24px;' +
    'display: flex;' +
    'justify-content: center;' +
    'align-items: center;' +
    'font-size: 12px;' +
    'color: #666666}',
    
    '.left{' +
    'background-image: url(/assets/img/leftPage.png);' +
    'background-repeat: no-repeat;' +
    'background-position: center;' +
    'width: 24px;' +
    'height: 24px}',

    '.right{' +
    'background-image: url(/assets/img/rightPage.png);' +
    'background-repeat: no-repeat;' +
    'background-position: center;' +
    'width: 24px;' +
    'height: 24px}',
  ]
})
export class PaginationComponent implements OnInit, OnChanges {
  showAfterDot: boolean = false;
  showBeforeDot: boolean = false;
  maxPage: number;
  jump: number;
  showList: Array<number>;
  @Input() total: number;
  @Input() pageSize: number = 10;
  @Input() nowPage: number = 1;
  @Output() nowPageChange = new EventEmitter();
  @Output() paginationEvent = new EventEmitter();
  constructor() {
    this.showList = [];
  }
  ngOnInit(): void {
    this.draw();
  }

  private draw() {
    this.showList = [];
    this.showBeforeDot = false;
    this.showAfterDot = false;
    if (this.total == 0) return;
    this.maxPage = Math.ceil(this.total / this.pageSize);

    if (this.nowPage <= 3) {
      if (this.maxPage <= 6) {
        for (let i = 2; i <= this.maxPage - 1; i++) {
          this.showList.push(i);
        }
      }

      if (this.maxPage > 6) {
        for (let i = 2; i <= 5; i++) {
          this.showList.push(i);
        }
        this.showAfterDot = true;
      }
    } else {
      if (this.nowPage - 2 > 1) {
        this.showList.push(this.nowPage - 2);
        if (this.nowPage - 2 > 2) {
          this.showBeforeDot = true;
        }
      }
      if (this.nowPage - 1 > 1) {
        this.showList.push(this.nowPage - 1);
      }
      if (this.nowPage != this.maxPage) {
        this.showList.push(this.nowPage);
      }

      if (this.nowPage + 1 < this.maxPage) {
        this.showList.push(this.nowPage + 1);
      }

      if (this.nowPage + 2 < this.maxPage) {
        this.showList.push(this.nowPage + 2);
        if (this.nowPage + 2 < this.maxPage - 1) {
          this.showAfterDot = true;
        }
      }
    }
  }

  jumpPage(page?) {
    if (page == null) {
      this.nowPage = this.jump;
    } else {
      if (page == 'before') {
        if (this.nowPage == 1) {
          return;
        }
        this.nowPage = this.nowPage - 1;
      } else
        if (page == 'after') {
          if (this.nowPage == this.maxPage) {
            return;
          }
          this.nowPage = this.nowPage + 1;
        } else {
          this.nowPage = page;
        }
    }

    if (this.nowPage > this.maxPage) {
      this.nowPage = this.maxPage;
    }

    this.draw();
    this.nowPageChange.emit(this.nowPage);
    this.paginationEvent.emit();
  }

  pressInput(event) {
    if (event.key == 'Enter') {
      this.jumpPage();
      this.jump = null;
    }
  }

  ngOnChanges(changes: SimpleChanges) {
    if (!changes.total.firstChange) {
      this.draw();
    }
  }
}
