import { Component, ElementRef, HostListener, Input, OnInit, ViewChild } from '@angular/core';

@Component({
  selector: 'dc-select',
  template: `
  <div class="dc-select-outer">
  <div class="dc-select-input">
    <input [(ngModel)]="defaultSelect.name" [readonly]="isReadonly">
    <span (click)="showOption($event)">show drop</span>
  </div>
  <ul class="dc-select-drop" #moreOption>
    <li *ngFor="let o of options" (click)="changeItem(o)">{{o.name}}</li>
  </ul>
</div>
  `,
  styles: [
    '.dc-select-outer{' +
    'position: relative;}',

    '.dc-select-input{' +
    'height: 30px;}',

    '.dc-select-drop{' +
    'display: none;' +
    'position: absolute;' +
    'left: 0;' +
    'top: 30px;' +
    'background-color: #fff;' +
    'border: 1px solid #ccc;' +
    'box-shadow: 0 1px 0.125rem rgba(115, 115, 115, 0.25);' +
    'z-index: 10;}'
  ]
})
export class SelectComponent implements OnInit {
  @Input() options;
  @Input() defaultSelect;
  @Input() isReadonly;
  @ViewChild('moreOption') moreOption: ElementRef;

  constructor() {

  }

  ngOnInit() {
    if (!this.options) {
      this.options = [
        {
          id: 1,
          name: 'a1',
        }, {
          id: 2,
          name: 'a2'
        }, {
          id: 3,
          name: 'a3'
        }, {
          id: 4,
          name: 'a4'
        }
      ];
    }
    if (!this.defaultSelect) {
      this.defaultSelect = this.options[0];
    }
  }

  @HostListener('document:click', ['$event'])
  onDocumentClick(ev) {
    this.moreOption.nativeElement.style.display = 'none';
  }

  showOption(ev) {
    ev.stopPropagation();
    ev.preventDefault();
    this.moreOption.nativeElement.style.display = 'block';
  }

  changeItem(item) {
    if (this.defaultSelect && this.defaultSelect.id === item.id) {
      return;
    }
    this.defaultSelect = item;
  }
}
